"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.declarationColonSpaceChecker = declarationColonSpaceChecker;

var _utils = require("../../utils");

var ruleName = "declaration-colon-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \":\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \":\"";
  }
});

exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    var validOptions = (0, _utils.validateOptions)(result, ruleName, {
      actual: expectation,
      possible: ["always", "never"]
    });
    if (!validOptions) {
      return;
    }

    declarationColonSpaceChecker(checker.after, root, result);
  };
};

function declarationColonSpaceChecker(locationChecker, root, result) {
  root.walkDecls(function (decl) {
    var declString = decl.toString();

    for (var i = 0, l = declString.length; i < l; i++) {
      if (declString[i] !== ":") {
        continue;
      }
      check(declString, i, decl);
      break;
    }
  });

  function check(source, index, node) {
    locationChecker({ source: source, index: index, err: function err(m) {
        return (0, _utils.report)({
          message: m,
          node: node,
          index: node.prop.toString().length + 1,
          result: result,
          ruleName: ruleName
        });
      }
    });
  }
}