"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mediaFeatureColonSpaceChecker = mediaFeatureColonSpaceChecker;

var _utils = require("../../utils");

var ruleName = "media-feature-colon-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \":\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \":\"";
  }
});

exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    var validOptions = (0, _utils.validateOptions)(result, ruleName, {
      actual: expectation,
      possible: ["always", "never"]
    });
    if (!validOptions) {
      return;
    }

    mediaFeatureColonSpaceChecker(checker.after, root, result);
  };
};

function mediaFeatureColonSpaceChecker(checkLocation, root, result) {
  root.walkAtRules(function (atRule) {
    var name = atRule.name;
    var params = atRule.params;

    // Only deal with @media at-rules
    if (name !== "media") {
      return;
    }

    (0, _utils.styleSearch)({ source: params, target: ":" }, function (match) {
      checkColon(params, match.startIndex, atRule);
    });
  });

  function checkColon(source, index, node) {
    checkLocation({ source: source, index: index, err: function err(m) {
        return (0, _utils.report)({
          message: m,
          node: node,
          index: index + 1 + node.name.length + node.raws.afterName.length,
          result: result,
          ruleName: ruleName
        });
      }
    });
  }
}