"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _cssStatementHasBlock = require("./cssStatementHasBlock");

var _cssStatementHasBlock2 = _interopRequireDefault(_cssStatementHasBlock);

/**
 * Given a CSS statement, return the string before the block.
 * For rules, this is the selector list (and surrounding whitespace).
 * For at-rules, this is the name and params (and surrounding whitespace).
 *
 * If there is no block, return undefined.
 *
 * @param {Rule|AtRule} statement - postcss rule or at-rule node
 * @param {object} options
 * @param {boolean} [options.noBefore] - Leave out the `before` string
 * @return {string|undefined}
 */

exports["default"] = function (statement) {
  var _ref = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var noBefore = _ref.noBefore;

  if (!(0, _cssStatementHasBlock2["default"])(statement)) {
    return;
  }

  var result = "";
  if (!noBefore) {
    result += statement.raws.before;
  }
  if (statement.type === "rule") {
    result += statement.selector;
  } else {
    result += "@" + statement.name + statement.raws.afterName + statement.params;
  }
  result += statement.raws.between;
  return result;
};

module.exports = exports["default"];